---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2006-01-24;36
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20060214&codiceRedaz=006G0046&dataVigenza=20251104
dataGU: 20060214
codiceRedaz: 006G0046
dataVigenza: 20251104
---

# ((Attuazione della direttiva (UE) 2019/1024
relativa all'apertura dei dati e al riutilizzo dell'informazione del settore pubblico che ha abrogato la direttiva 2003/98/CE))

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76 e 87 della Costituzione;

Visto l'articolo 117 della Costituzione;

((Vista la legge 22 aprile 2021, n. 53 e, in particolare, l'articolo 1 e l'allegato A;

Vista la direttiva (UE) 2019/1024 del Parlamento europeo e del Consiglio, del 20 giugno 2019, relativa all'apertura dei dati e al riutilizzo dell'informazione del settore pubblico;))

Vista la legge 18 aprile 2005, n. 62, ed in particolare l'articolo 1 e l'allegato A;

Vista la direttiva 2003/98/CE del Parlamento europeo e del Consiglio del 17 novembre 2003, relativa al riutilizzo dell'informazione del settore pubblico;

((Visto il regolamento (UE) n. 2016/679 del Parlamento europeo e del Consiglio, del 27 aprile 2016, relativo alla protezione delle persone fisiche con riguardo al trattamento dei dati personali, nonche' alla libera circolazione di tali dati e che abroga la direttiva 95/46/CE;))

Vista la legge 22 aprile 1941, n. 633;

Vista la legge 24 ottobre 1977, n. 801;

Vista la legge 7 agosto 1990, n. 241;

Visto il decreto legislativo 17 marzo 1995, n. 157;

Vista la legge 7 giugno 2000, n. 150;

Visto il decreto legislativo 18 agosto 2000, n. 267;

Visto il decreto legislativo 30 giugno 2003, n. 196;

Visto il decreto legislativo 11 novembre 2003, n. 333;

Vista la legge 30 dicembre 2004, n. 311;

Visto il decreto legislativo 7 marzo 2005, n. 82;

((Vista la legge 3 agosto 2007, n. 124;

Visto il decreto legislativo 27 gennaio 2010, n. 32;

Visto il decreto legislativo 14 marzo 2013, n. 33;

Visto il decreto legislativo 18 maggio 2015, n. 102;

Visto il decreto legislativo 18 aprile 2016, n. 50;))

Acquisito il parere del Garante per la protezione dei dati personali;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 28 ottobre 2005;

Sulla proposta del Ministro per le politiche comunitarie e del Ministro per l'innovazione e le tecnologie, di concerto con i Ministri degli affari esteri, della giustizia, dell'economia e delle finanze e per la funzione pubblica;

Emana il seguente decreto legislativo:

## Art. 1. - Oggetto ed ambito di applicazione

1. Il presente decreto legislativo disciplina le modalita' di riutilizzo dei documenti contenenti dati pubblici nella disponibilita' delle pubbliche amministrazioni e degli organismi di diritto pubblico ((e delle imprese pubbliche e private, ai sensi di quanto previsto dai commi 2-ter e 2-quater)).

2. Le pubbliche amministrazioni e gli organismi di diritto pubblico provvedono affinche' i documenti cui si applica il presente decreto legislativo siano riutilizzabili a fini commerciali o non commerciali secondo le modalita' previste dal medesimo decreto, inclusi i documenti i cui diritti di proprieta' intellettuale sono detenuti da biblioteche, comprese le biblioteche universitarie, i musei e gli archivi, qualora il riutilizzo di questi ultimi documenti sia autorizzato in conformita' alle disposizioni di cui alla Parte II, Titolo II, ((Capo I e)) Capo III, del decreto legislativo 22 gennaio 2004, n. 42, nonche' a quelle di cui alla Parte II, Titolo VII, Capo II, del decreto legislativo 30 giugno 2003 n. 196.

((

2-bis. Il presente decreto si applica ai dati della ricerca conformemente alle condizioni di cui all'articolo 9-bis.

2-ter. Fatto salvo quanto previsto all'articolo 3, comma 1, lettera a-bis), il presente decreto disciplina, altresi', il riutilizzo dei documenti nella disponibilita' delle imprese pubbliche:

- a) attive nei settori di cui agli articoli da 115 a 121 del decreto legislativo 18 aprile 2016, n. 50;
- b) che agiscono in qualita' di operatori di servizio pubblico ai sensi dell'articolo 2 del regolamento (CE) n. 1370/2007;
- c) che agiscono in qualita' di vettori aerei che assolvono oneri di servizio pubblico ai sensi dell'articolo 16 del regolamento (CE) n. 1008/2008;
- d) che agiscono in qualita' di armatori comunitari che assolvono obblighi di servizio pubblico ai sensi dell'articolo 4 del regolamento (CEE) n. 3577/1992.

2-quater. La disciplina di cui al comma 2-ter si applica anche alle imprese private di trasporto che sono soggette ad obblighi di servizio pubblico ai sensi dell'articolo 16 del regolamento (CE) n. 1008/2008 e, in generale, ai gestori di servizi pubblici in relazione ai servizi di pubblico interesse;

2-quinquies. Il presente decreto disciplina altresi' il riutilizzo dei documenti ai quali si applica il decreto legislativo 27 gennaio 2010, n. 32, di recepimento della direttiva 2007/2/CE.

))

3. Il presente decreto si applica altresi' quando i documenti di cui al comma 1 sono gia' stati diffusi per il loro riutilizzo dai soggetti ivi indicati. E' in ogni caso assicurata la parita' di trattamento tra tutti i riutillizzatori, salvo quanto previsto dall'articolo 11.

4. COMMA ABROGATO DAL D.LGS. 18 MAGGIO 2015, N. 102.

## Art. 2. - Definizioni

1. Ai fini del presente decreto si intende per: ((a) pubbliche amministrazioni: le amministrazioni di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, ivi comprese le autorita' di sistema portuale, le autorita' amministrative indipendenti di garanzia, vigilanza e regolazione, nonche' i loro consorzi o associazioni a qualsiasi fine istituiti;)) ((a-bis) imprese pubbliche: le imprese definite all'articolo 3, comma 1, lettera t), del decreto legislativo 18 aprile 2016, n. 50;)) ((b) organismi di diritto pubblico: gli organismi definiti all'articolo 3, comma 1, lettera d) del decreto legislativo 18 aprile 2016, n. 50;)) b-bis) universita': qualsiasi organismo pubblico che fornisce istruzione post-secondaria superiore che conduce a titoli di studio accademici; c) documento: la rappresentazione di atti, fatti e dati a prescindere dal supporto ((, cartaceo o elettronico, registrazione sonora, visiva o audiovisiva o qualsiasi parte di tale contenuto)) nella disponibilita' della pubblica amministrazione o dell'organismo di diritto pubblico. La definizione di documento non comprende i programmi informatici; c-bis) formato leggibile meccanicamente: un formato di file strutturato in modo tale da consentire alle applicazioni software di individuare, riconoscere ed estrarre facilmente dati specifici, comprese dichiarazioni individuali di fatto e la loro struttura interna; c-ter) formato aperto: il formato di cui all'articolo ((1, comma 1, lettera l-bis, del decreto legislativo 7 marzo 2005, n. 82)), del decreto legislativo 7 marzo 2005, n. 82, e successive modificazioni; ((c-quater) dati di tipo aperto: dati come definiti dall'articolo 1, comma 1, lettera l-ter), del decreto legislativo 7 marzo 2005, n. 82;)) ((c-quinquies) anonimizzazione: la procedura mirante a rendere anonimi documenti, rendendoli non riconducibili a una persona fisica identificata o identificabile, ovvero la procedura mirante a rendere anonimi dati personali in modo da impedire o da non consentire piu' l'identificazione dell'interessato; c-sexies) dati dinamici: documenti informatici, soggetti ad aggiornamenti frequenti o in tempo reale, in particolare a causa della loro volatilita' o rapida obsolescenza; c-septies) dati della ricerca: documenti informatici, diversi dalle pubblicazioni scientifiche, raccolti o prodotti nel corso della ricerca scientifica e utilizzati come elementi di prova nel processo di ricerca, o comunemente accettati nella comunita' di ricerca come necessari per convalidare le conclusioni e i risultati della ricerca; c-octies) serie di dati di elevato valore: documenti il cui riutilizzo e' associato a importanti benefici per la societa', l'ambiente e l'economia, in considerazione della loro idoneita' per la creazione di servizi, applicazioni a valore aggiunto e nuovi posti di lavoro, nonche' del numero dei potenziali beneficiari dei servizi e delle applicazioni a valore aggiunto basati su tali serie di dati;)) d) dato pubblico: il dato conoscibile da chiunque; ((e) riutilizzo: l'uso da parte di persone fisiche o giuridiche di documenti detenuti da: 1) pubbliche amministrazioni o organismi di diritto pubblico, per fini commerciali o per fini non commerciali, diversi da quelli istituzionali per i quali i documenti sono stati prodotti, fatta eccezione per lo scambio di documenti tra pubbliche amministrazioni, o organismi di diritto pubblico, ovvero tra amministrazioni e organismi di diritto pubblico, posto in essere esclusivamente nell'ambito dell'espletamento dei compiti istituzionali di cui sono titolari; 2) imprese pubbliche e imprese private di cui all'articolo 1, comma 2-quater, per fini commerciali o per fini non commerciali, diversi da quelli relativi alla fornitura dei servizi di interesse generale per i quali i documenti sono stati prodotti, fatta eccezione per lo scambio di documenti tra imprese pubbliche e pubbliche amministrazioni o organismi di diritto pubblico posto in essere esclusivamente nell'ambito dell'espletamento dei compiti istituzionali delle pubbliche amministrazioni;)) f) scambio di documenti: la cessione di documenti finalizzata esclusivamente all'adempimento di compiti istituzionali fra i soggetti di cui alle lettere a) e b); ((f-bis) interfaccia tra programmi applicativi (API): insieme di funzioni, procedure, operazioni disponibili al programmatore, di solito raggruppate a formare un insieme di strumenti specifici per l'espletamento di un determinato compito;)) g) dati personali: i dati definiti tali ((dall'articolo 4, numero 1, del regolamento UE 2016/679)); h) licenza standard per il riutilizzo: il contratto, o altro strumento negoziale, ((ove possibile redatto in forma elettronica, compatibile con le licenze pubbliche standardizzate disponibili online, nel quale sono definite le modalita' di riutilizzo in formato digitale dei documenti)); i) titolare del dato: la pubblica amministrazione o l'organismo di diritto pubblico che ha originariamente formato per uso proprio o commissionato ad altro soggetto pubblico o privato il documento che rappresenta il dato, o che ne ha la disponibilita'. ((i-bis) utile ragionevole sugli investimenti: una percentuale della tariffa complessiva, in aggiunta a quella necessaria per recuperare i costi ammissibili, non superiore a cinque punti percentuali oltre il tasso di interesse fisso della BCE; i-ter) terzo: qualsiasi persona fisica o giuridica diversa dalle pubbliche amministrazioni e dagli organismi di diritto pubblico o dalle imprese pubbliche che detengono i dati.))

## Art. 3. - Documenti esclusi dall'applicazione del decreto

1. ((Il presente decreto non si applica ai seguenti documenti:))

- a) quelli detenuti per finalita' che esulano dall'ambito dei compiti istituzionali della pubblica amministrazione o dell'organismo di diritto pubblico, a condizione che la portata di detti compiti sia trasparente e soggetta a revisione;
- a-bis) quelli nella disponibilita' di imprese pubbliche: 1) prodotti al di fuori dell'ambito della prestazione di servizi di interesse generale; 2) connessi ad attivita' direttamente esposte alla concorrenza e non soggette alle norme in materia di appalti;
- b) quelli nella disponibilita' delle emittenti di servizio pubblico e delle societa' da esse controllate e da altri organismi o loro societa' controllate per l'adempimento di un compito di radiodiffusione di servizio pubblico;
- c) quelli nella disponibilita' di istituti di istruzione ((secondaria e inferiore e, nel caso di tutti gli altri istituti di istruzione, ai documenti diversi da quelli di cui all'articolo 1, comma 2-bis, del presente decreto));
- d) quelli nella disponibilita' di enti culturali diversi dalle biblioteche ((,comprese quelle universitarie)), dai musei e dagli archivi;
- e) quelli comunque nella disponibilita' degli organismi di cui ((alla legge 3 agosto 2007, n. 124));
- f) LETTERA ABROGATA DALLA L. 4 GIUGNO 2010, N. 96;
- g) quelli esclusi dall'accesso ai sensi dell'articolo 24 della legge 7 agosto 1990, n. 241, ((nonche' ai sensi dell'articolo 5-bis del decreto legislativo 14 marzo 2013, n. 33,)) o per motivi di tutela del segreto statistico, quali disciplinati dall'articolo 9 del decreto legislativo 6 settembre 1989. n. 322;
- h) quelli sui cui terzi detengono diritti di proprieta' intellettuale ai sensi della legge 22 aprile 1941, n. 633, ovvero diritti di proprieta' industriale ai sensi del decreto legislativo 10 febbraio 2005, n. 30.
- h-bis) quelli, non contenenti dati pubblici, il cui accesso e' disciplinato dal Capo V della legge 7 agosto 1990, n. 241;
- h-ter) parti di documenti contenenti solo logotipi, stemmi e distintivi;
- h-quater) quelli il cui accesso, ai sensi delle previsioni del regolamento UE 2016/679 e del decreto legislativo 30 giugno 2003, n. 196 nonche' del decreto legislativo 18 maggio 2018, n. 51, e' escluso o limitato, ovvero risulti pregiudizievole per la tutela della vita privata e dell'integrita' degli individui, nonche' alle parti di documenti accessibili che contengono dati personali il cui riutilizzo e' stato definito per legge incompatibile con le previsioni delle suddette disposizioni normative;
- h-quinquies) quelli il cui accesso e' escluso o limitato per motivi di protezione delle informazioni sensibili relative alle infrastrutture critiche definite all'articolo 2 del decreto legislativo 11 aprile 2011, n. 61;
- h-sexies) documenti diversi da quelli di cui all'articolo 2, comma 1, lettera c-septies), nella disponibilita' di organizzazioni che svolgono attivita' di ricerca e di organizzazioni che finanziano la ricerca, comprese le organizzazioni preposte al trasferimento dei risultati della ricerca.

((

1-bis. Le pubbliche amministrazioni e gli organismi di diritto pubblico non possono esercitare il diritto di cui all'articolo 64-quinquies della legge 22 aprile 1941, n. 633 per impedire il riutilizzo di documenti o di limitare il riutilizzo, salvo i limiti stabiliti dal presente decreto.

))

## Art. 4. - Norma di salvaguardia

1. Sono fatte salve:

- a) la disciplina sulla protezione dei dati personali di cui al decreto legislativo 30 giugno 2003, n. 196;
- b) la disciplina sulla protezione del diritto d'autore di cui alla legge 22 aprile 1941, n. 633. Gli obblighi previsti dal presente decreto legislativo si applicano compatibilmente con le disposizioni degli accordi internazionali sulla protezione dei diritti di proprieta' intellettuale e, in particolare, della Convenzione di Berna per la protezione delle opere letterarie ed artistiche del 1886, ratificata ai sensi della legge 20 giugno 1978, n. 399, dell'Accordo TRIPS sugli aspetti dei diritti di proprieta' intellettuale attinenti al commercio del 1994, ratificato e reso esecutivo ai sensi della legge 29 dicembre 1994, n. 747, e del Trattato sul diritto d'autore (WCT), adottato a Ginevra il 20 dicembre 1996 ed entrato in vigore per tutti gli Stati membri dell'Unione Europea il 14 marzo 2010;
- c) la disciplina in materia di accesso ai documenti amministrativi, di cui al Capo V della legge 7 agosto 1990, n. 241;
- d) LETTERA ABROGATA DALLA L. 4 GIUGNO 2010, N. 96;
- e) le disposizioni in materia di proprieta' industriale di cui al decreto legislativo 10 febbraio 2005, n. 30;
- f) LETTERA ABROGATA DALLA L. 4 GIUGNO 2010, N. 96.

## Art. 5. - (( (Richiesta di riutilizzo di documenti). ))

((

1. Le pubbliche amministrazioni e gli organismi di diritto pubblico esaminano le richieste e rendono disponibili i documenti, con le modalita' di cui al comma 2, entro il termine di trenta giorni dalla richiesta, prorogabile di ulteriori venti giorni nel caso in cui le richieste siano numerose o complesse. Di tale proroga e' data comunicazione al richiedente entro ventuno giorni dalla richiesta.

2. In caso di decisione positiva, i documenti sono resi disponibili, ove possibile, in forma elettronica e, se necessario, attraverso una licenza.

3. I provvedimenti di diniego sono motivati sulla base delle disposizioni del presente decreto.

4. Nel caso in cui il riutilizzo e' negato ai sensi dell'articolo 3, comma 1, lettera h), per la parte relativa ai diritti di proprieta' intellettuale, le pubbliche amministrazioni o gli organismi di diritto pubblico indicano la persona fisica o giuridica titolare del diritto, se e' nota, oppure il licenziante dal quale il titolare del dato stesso ha ottenuto il materiale. Le biblioteche, comprese quelle universitarie, i musei e gli archivi non sono tenuti a fornire la suddetta indicazione.

5. In caso di diniego, il richiedente puo' esperire i mezzi di tutela previsti dall'articolo 25, commi 4 e 5, della legge 7 agosto 1990, n. 241. Degli stessi e' data comunicazione al richiedente con il provvedimento di diniego.

6. Le imprese pubbliche, gli istituti di istruzione, le organizzazioni che svolgono attivita' di ricerca, le organizzazioni che finanziano la ricerca e gli organismi di cui agli articoli 4, 6 e 7 della legge 3 agosto 2007, n. 124, definiscono i termini e le modalita' di riutilizzo dei dati secondo i rispettivi ordinamenti.

))

## Art. 6. - (( (Formati disponibili). ))

((

1. Le pubbliche amministrazioni, gli organismi di diritto pubblico e le imprese pubbliche mettono a disposizione i propri documenti, ove possibile insieme ai rispettivi metadati, secondo le modalita' e i formati previsti dall'articolo 2, lettere c-bis) e c-ter), nel rispetto delle regole tecniche di cui all'articolo 12.

2. Le pubbliche amministrazioni e gli organismi di diritto pubblico non hanno l'obbligo di adeguare i documenti o di crearne nuovi per soddisfare la richiesta, ne' l'obbligo di fornire estratti di documenti se cio' comporta difficolta' sproporzionate, che implicano attivita' eccedenti la semplice manipolazione. Le pubbliche amministrazioni e gli organismi di diritto pubblico provvedono ai sensi del periodo precedente con provvedimento motivato.

3. Le pubbliche amministrazioni e gli organismi di diritto pubblico non hanno l'obbligo di continuare a produrre e a conservare in uno specifico formato i documenti per permetterne il riutilizzo.

4. Le pubbliche amministrazioni, gli organismi di diritto pubblico e le imprese pubbliche producono e rendono disponibili i documenti che rientrano nell'ambito di applicazione del presente decreto legislativo secondo il principio dell'apertura fin dalla progettazione e per impostazione predefinita.

5. Fermo quanto previsto dal comma 2, le pubbliche amministrazioni e gli organismi di diritto pubblico rendono disponibili i dati dinamici per il riutilizzo immediatamente dopo la raccolta tramite API adeguate e, ove possibile, come download in blocco.

6. Nei casi in cui l'espletamento dell'attivita' di cui al comma precedente ecceda le capacita' finanziarie e tecniche delle pubbliche amministrazioni e degli organismi di diritto pubblico, imponendo uno sforzo sproporzionato, i dati dinamici sono resi disponibili per il riutilizzo entro un termine e con temporanee restrizioni tecniche, da definirsi con apposito provvedimento dei titolari dei suddetti dati, tali da non pregiudicare indebitamente lo sfruttamento del loro potenziale economico e sociale.

7. I commi precedenti si applicano anche ai documenti delle imprese pubbliche e delle imprese private di cui all'articolo 1, comma 2-quater, resi disponibili per il riutilizzo.

8. Le serie di dati di elevato valore, di cui all'articolo 12-bis sono messe a disposizione per il riutilizzo in formato leggibile meccanicamente, tramite opportune API e, ove possibile, come download in blocco.

9. Nel caso in cui l'espletamento dell'attivita' del comma 8 coinvolga dati territoriali e del monitoraggio ambientale, necessari per gli scopi delle politiche ambientali e delle politiche o delle attivita' che possono avere ripercussioni sull'ambiente si applicano le regole tecniche definite dalla Direttiva 2007/2/CE del Parlamento Europeo e del Consiglio del 14 marzo 2007.

))

## Art. 7. - (Tariffazione)

1. I dati sono resi disponibili gratuitamente ((, fatta salva la possibilita' di recuperare i costi marginali sostenuti per la riproduzione, messa a disposizione e divulgazione dei documenti, nonche' per l'anonimizzazione di dati personali o per le misure adottate per proteggere le informazioni commerciali a carattere riservato)).

2. ((COMMA ABROGATO DAL D.LGS. 8 NOVEMBRE 2021, N. 200)).

3. ((Il comma 1 non trova applicazione per:))

- a) ((le)) biblioteche, comprese quelle universitarie, i musei e gli archivi;
- b) ((le)) pubbliche amministrazioni e ((gli)) organismi di diritto pubblico che devono generare utili per coprire una parte sostanziale dei costi inerenti allo svolgimento dei propri compiti di servizio pubblico;
- c) le imprese pubbliche.

((

3-bis. Nelle ipotesi in cui i soggetti individuati nel precedente comma 3, lettera a), richiedano il pagamento di un corrispettivo, il totale delle entrate provenienti dalla fornitura e dall'autorizzazione al riutilizzo dei documenti in un esercizio contabile non puo' superare i costi marginali del servizio reso, comprendenti i costi di raccolta, produzione, riproduzione, diffusione, archiviazione dei dati, conservazione e gestione dei diritti e, ove applicabile, di anonimizzazione dei dati personali e delle misure adottate per proteggere le informazioni commerciali a carattere riservato, maggiorati di un utile ragionevole sugli investimenti.

3-ter. L'elenco delle pubbliche amministrazioni e degli organismi di diritto pubblico di cui al precedente comma 3, lettera b), e' definito e aggiornato periodicamente, con decreto del Ministro dell'economia e delle finanze ed e' pubblicato sui rispettivi siti istituzionali.

))

((

4. Per i casi di cui al comma 3, lettere b) e c), l'importo totale delle tariffe e' calcolato in base a parametri oggettivi, trasparenti e verificabili ed e' determinato secondo il criterio del costo marginale del servizio con decreti dei Ministri competenti, di concerto con il Ministro dell'economia e delle finanze sentita l'Agenzia per l'Italia digitale, sono fatte salve le disposizioni di cui agli articoli 1, commi 370, 371 e 372, della legge 30 dicembre 2004, n. 311 e 5, comma 4-bis, del decreto-legge 13 maggio 2011, n. 70, convertito, con modificazioni, dalla legge 12 luglio 2011, n. 106.

))

((

4-bis. Nei casi di cui al comma 3, lettere b) e c), il totale delle entrate ricavate, per ciascuna amministrazione o organismo di diritto pubblico, dalla fornitura e dall'autorizzazione al riutilizzo dei documenti in un esercizio contabile non deve superare i costi, maggiorati di un utile ragionevole sugli investimenti, relativi alla raccolta, produzione, riproduzione, diffusione e archiviazione dei dati e, ove applicabile, di anonimizzazione dei dati personali e delle misure adottate per proteggere le informazioni commerciali a carattere riservato.

))

5. ((COMMA ABROGATO DAL D.LGS. 8 NOVEMBRE 2021, N. 200)).

6. ((COMMA ABROGATO DAL D.LGS. 8 NOVEMBRE 2021, N. 200)).

7. ((COMMA ABROGATO DAL D.LGS. 8 NOVEMBRE 2021, N. 200)).

8. Gli introiti delle tariffe di cui ai commi ((precedenti)) sono versati all'entrata del bilancio dello Stato, per essere riassegnati, ai sensi del decreto del Presidente della Repubblica 10 novembre 1999, n. 469, allo stato di previsione delle Amministrazioni interessate.

9. Gli enti territoriali e gli altri enti ed organismi pubblici, sentita l'Agenzia per l'Italia digitale, determinano, rispettivamente con proprie disposizioni o propri atti deliberativi, gli importi delle tariffe e le relative modalita' di versamento, sulla base dei criteri indicati ((ai commi 4 e 4-bis)).

((

9-bis. Il riutilizzo e' comunque gratuito:

- a) per le serie di dati di elevato valore secondo quanto previsto dall'articolo 12-bis, comma 1, lettera a);
- b) per i dati della ricerca di cui all'articolo 9-bis.

9-ter. Qualora siano applicate tariffe per il riutilizzo di documenti, le pubbliche amministrazioni, gli organismi di diritto pubblico e le imprese pubbliche competenti definiscono in anticipo e rendono disponibili sui propri siti istituzionali, dandone comunicazione all'Agenzia per l'Italia Digitale, le condizioni applicabili e l'effettivo ammontare delle tariffe, compresa la base di calcolo utilizzata per tali tariffe e gli elementi presi in considerazione nel calcolo di tali tariffe.

))

## Art. 8. - (( (Contenuti delle licenze standard per il riutilizzo). ))

((

1. Le pubbliche amministrazioni, gli organismi di diritto pubblico e le imprese pubbliche nonche' le imprese private di cui all'articolo 1, comma 2-quater, adottano licenze standard, disponibili in formato digitale, per il riutilizzo dei propri documenti.

2. Il riutilizzo di documenti non e' soggetto a condizioni, salvo che tali condizioni non siano obiettive, proporzionate, non discriminatorie e siano giustificate da un pubblico interesse.

3. Se una pubblica amministrazione o un organismo di diritto pubblico riutilizza documenti per attivita' commerciali che esulano dall'ambito dei suoi compiti di servizio pubblico, la messa a disposizione dei documenti in questione per tali attivita' e' soggetta alle stesse condizioni e alle medesime tariffe applicate agli altri riutilizzatori.

4. Le condizioni poste per il riutilizzo di documenti non comportano discriminazioni per categorie analoghe di riutilizzo, compreso il riutilizzo transfrontaliero, ne' possono costituire ostacolo alla concorrenza.

))

## Art. 9. - (( (Strumenti di ricerca di documenti disponibili) ))

((

1. Le pubbliche amministrazioni, gli organismi di diritto pubblico, le imprese pubbliche e le imprese private di cui all'articolo 1, comma 2-quater, cui si applica il presente decreto, anche alla luce della strategia nazionale in materia di dati, pubblicano e aggiornano annualmente sui propri siti istituzionali gli elenchi delle categorie di dati detenuti ai fini del riutilizzo. Individuano, inoltre, le modalita' per facilitare la ricerca, anche interlinguistica, dei documenti disponibili per il riutilizzo, insieme ai rispettivi metadati, ove possibile accessibili on-line e in formati leggibili meccanicamente.

2. Per la ricerca di dati in formato aperto, le pubbliche amministrazioni, gli organismi di diritto pubblico, le imprese pubbliche e le imprese private di cui all'articolo 1, comma 2-quater, utilizzano il catalogo nazionale dei dati aperti gestito dall'Agenzia per l'Italia digitale, come punto di accesso unico alle serie di dati, ad eccezione dei set di dati territoriali che sono disponibili anche nel Repertorio Nazionale dei dati Territoriali.

3. Le pubbliche amministrazioni e gli organismi di diritto pubblico utilizzano le modalita' per facilitare la conservazione dei documenti disponibili per il riutilizzo secondo quanto previsto dall'articolo 44 del decreto legislativo 7 marzo 2005, n. 82.

))

## Art. 9-bis. - (( (Dati della ricerca). ))

((

1. I dati della ricerca sono riutilizzabili a fini commerciali o non commerciali conformemente a quanto previsto dal presente decreto legislativo, nel rispetto della disciplina sulla protezione dei dati personali, ove applicabile, degli interessi commerciali, nonche' della normativa in materia di diritti di proprieta' intellettuale ai sensi della legge 22 aprile 1941, n. 633, e dei diritti di proprieta' industriale ai sensi del decreto legislativo 10 febbraio 2005, n. 30.

2. La previsione del comma 1 si applica nelle ipotesi in cui i dati siano il risultato di attivita' di ricerca finanziata con fondi pubblici e quando gli stessi dati siano resi pubblici, anche attraverso l'archiviazione in una banca dati pubblica, da ricercatori, organizzazioni che svolgono attivita' di ricerca e organizzazioni che finanziano la ricerca, tramite una banca dati gestita a livello istituzionale o su base tematica.

3. I dati della ricerca di cui ai commi precedenti rispettano i requisiti di reperibilita', accessibilita', interoperabilita' e riutilizzabilita'.

))

## Art. 10.

((ARTICOLO ABROGATO DAL D.LGS. 8 NOVEMBRE 2021, N. 200))

## Art. 11. - (( (Accordi di esclusiva). ))

((

1. I documenti delle pubbliche amministrazioni, degli organismi di diritto pubblico, delle imprese pubbliche e delle imprese private di cui all'articolo 1, comma 2-quater, possono essere riutilizzati da tutti gli operatori interessati alle condizioni previste dal presente decreto, anche qualora uno o piu' soggetti stiano gia' procedendo allo sfruttamento di prodotti a valore aggiunto basati su tali documenti. I contratti o gli altri accordi tra i terzi e le pubbliche amministrazioni, gli organismi di diritto pubblico e le imprese pubbliche in possesso dei documenti non stabiliscono diritti esclusivi.

2. Se per l'erogazione di un servizio d'interesse pubblico e' necessario un diritto esclusivo, la fondatezza del motivo per l'attribuzione di tale diritto esclusivo e' soggetta a valutazione periodica con cadenza almeno triennale. Gli accordi di esclusiva sono resi pubblici sul sito istituzionale almeno due mesi prima che abbiano effetto. I termini di tali accordi sono trasparenti e sono resi pubblici sul sito istituzionale. Il presente comma non si applica alla digitalizzazione di risorse culturali.

3. In deroga al comma 1, se il diritto esclusivo riguarda la digitalizzazione di risorse culturali, il periodo di esclusiva non eccede di norma i sette anni. Nel caso in cui tale periodo ecceda i sette anni, la sua durata e' soggetta a riesame nel corso dell'ottavo anno e, se del caso, successivamente ogni cinque anni. Gli accordi che concedono diritti di esclusiva sono trasparenti e sono resi pubblici online, fatto salvo il diritto delle pubbliche amministrazioni e degli organismi di diritto pubblico interessati di ricevere, a titolo gratuito, una copia delle risorse culturali digitalizzate come parte di tale accordo. Tale copia e' resa disponibile per il riutilizzo al termine del periodo di esclusiva.

4. Le disposizioni che, pur non concedendo espressamente un diritto esclusivo, limitano la disponibilita' di riutilizzo di documenti da parte di soggetti diversi dal terzo che partecipa all'accordo, sono rese pubbliche on-line almeno due mesi prima che le stesse abbiano efficacia. L'effetto di tali disposizioni e' soggetto a valutazione periodica con cadenza almeno triennale. I termini definitivi degli accordi sono trasparenti e resi pubblici on-line.

5. I diritti di esclusiva esistenti al 17 luglio 2013 non conformi alle condizioni previste per beneficiare delle deroghe di cui ai commi 2 e 3 e che sono stati conclusi da pubbliche amministrazioni o da organismi di diritto pubblico cessano alla scadenza del contratto e comunque il 18 luglio 2043, ove la scadenza del contratto sia successiva a tale data.

6. I diritti di esclusiva esistenti al 16 luglio 2019, non conformi alle condizioni previste per beneficiare delle deroghe di cui ai commi 2 e 3, conclusi da imprese pubbliche, cessano alla scadenza del contratto e comunque il 17 luglio 2049, ove la scadenza del contratto sia successiva a tale data.))

--------------- AGGIORNAMENTO (2) Il D.Lgs. 18 maggio 2015, n. 102 ha disposto (con l'art. 3, comma 1) che "Gli accordi di esclusiva di cui all'articolo 1, comma 9, lettera a), del presente decreto legislativo stipulati dopo il 17 luglio 2013 sono adeguati alle disposizioni del predetto comma 9 entro il termine di sei mesi dalla data di entrata in vigore del medesimo decreto. Decorso tale termine, la durata dei predetti accordi e' ridotta, ove superiore, a dieci anni, fermo restando la possibilita' di riesame ai sensi del secondo periodo della medesima lettera a) del comma 9".

## Art. 12. - (( (Regole tecniche). ))

((

1. L'Agenzia per l'Italia digitale adotta entro 180 giorni le Linee guida contenenti le regole tecniche per l'attuazione del presente decreto con le modalita' previste dall'articolo 71, del decreto legislativo 7 marzo 2005, n. 82. In caso di violazione delle disposizioni introdotte dalle Linee guida, il soggetto interessato puo' rivolgersi al difensore civico per il digitale di cui all'articolo 17, comma 1-quater, del Codice dell'amministrazione digitale e si applicano le sanzioni previste dall'articolo 18-bis, comma 5, dello stesso Codice.

))

## Art. 12-bis. - (( (Serie specifiche di dati di elevato valore). ))

((

1. Alle specifiche serie di dati di elevato valore individuate dalla Commissione europea ai sensi dell'articolo 14, paragrafo 1, della direttiva UE n. 1024/2019 all'interno delle categorie previste dall'articolo 13 e dall'allegato I della medesima direttiva, si applicano le seguenti disposizioni:

- a) sono rese disponibili gratuitamente, salvo che: 1) gli atti di esecuzione di cui all'articolo 14, paragrafo 1, della direttiva non prevedano per specifiche serie di dati in possesso delle imprese pubbliche l'esenzione dall'obbligo di messa a disposizione gratuita, secondo quanto previsto dall'articolo 14, paragrafo 3, della direttiva; 2) siano detenuti da biblioteche, comprese quelle universitarie, da musei o da archivi; 3) siano detenuti da amministrazioni pubbliche o organismi di diritto pubblico che devono generare utili per coprire una parte sostanziale dei costi inerenti allo svolgimento dei propri compiti istituzionali e la messa a disposizione gratuita di tali dati avrebbe un impatto sostanziale sul bilancio dei suddetti enti. In tal caso i suddetti enti possono applicare le tariffe previste dall'articolo 7 per un periodo di due anni dalla data di entrata in vigore dell'atto di esecuzione adottato dalla Commissione ai sensi dell'articolo 14, paragrafo 1, della direttiva;
- b) sono rese leggibili meccanicamente;
- c) sono fornite mediante API;
- d) sono fornite come download in blocco, se del caso.

2. L'Istituto Geografico Militare, al fine di garantire la qualita' dei dati di cui al precedente comma 1, lettera a), in ambito nazionale raccoglie, produce, aggiorna, riproduce e diffonde nel settore geografico i dati geospaziali. La cessione dei documenti di interesse nazionale all'Istituto da parte degli altri organismi di diritto pubblico e' finalizzata all'adempimento dei compiti istituzionali e alla produzione dei documenti cartografici dello Stato dichiarati ufficiali dallo stesso Istituto. Le societa' private che riusano i dati geospaziali resi disponibili dall'Istituto devono fornire copia dei documenti derivati che su richiesta, previa verifica, possono essere dichiarati conformi ai requisiti tecnici di qualita' o alle specifiche adottate dall'Istituto. I rilevamenti eseguiti, per qualsiasi scopo, sul territorio nazionale da organismi di diritto pubblico o privati, devono essere comunicati all'Istituto ai fini di un eventuale aggiornamento dei documenti cartografici dello Stato.

))

## Art. 13. - (( (Clausola di invarianza finanziaria). ))

